==> pulsar-client-api-2.3.1-sources.jar: org/apache/pulsar/client/api/EncryptionKeyInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.api;

import java.util.Map;

/**
 * EncryptionKeyInfo contains the encryption key and corresponding metadata which contains additional information about
 * the key such as version, timestamp.
 */
public class EncryptionKeyInfo {

    private Map<String, String> metadata = null;
    private byte[] key = null;

    public EncryptionKeyInfo() {
        this.key = null;
        this.metadata = null;
    }

    public EncryptionKeyInfo(byte[] key, Map<String, String> metadata) {
        this.key = key;
        this.metadata = metadata;
    }

    public byte[] getKey() {
        return key;
    }

    public void setKey(byte[] key) {
        this.key = key;
    }

    public Map<String, String> getMetadata() {
        return metadata;
    }

    public void setMetadata(Map<String, String> metadata) {
        this.metadata = metadata;
    }
}

==> pulsar-client-api-2.10.0.0-rc8-sources.jar: org/apache/pulsar/client/api/EncryptionKeyInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.api;

import java.util.Map;
import org.apache.pulsar.common.classification.InterfaceAudience;
import org.apache.pulsar.common.classification.InterfaceStability;

/**
 * EncryptionKeyInfo contains the encryption key and corresponding metadata which contains additional information about
 * the key such as version, timestamp.
 */
@InterfaceAudience.Private
@InterfaceStability.Stable
public class EncryptionKeyInfo {

    private Map<String, String> metadata;
    private byte[] key;

    public EncryptionKeyInfo() {
        this.key = null;
        this.metadata = null;
    }

    public EncryptionKeyInfo(byte[] key, Map<String, String> metadata) {
        this.key = key;
        this.metadata = metadata;
    }

    public byte[] getKey() {
        return key;
    }

    public void setKey(byte[] key) {
        this.key = key;
    }

    public Map<String, String> getMetadata() {
        return metadata;
    }

    public void setMetadata(Map<String, String> metadata) {
        this.metadata = metadata;
    }
}
